elephant.kernels.RectangularKernel
==================================

.. currentmodule:: elephant.kernels

.. autoclass:: RectangularKernel
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RectangularKernel.__init__
      ~RectangularKernel.boundary_enclosing_area_fraction
      ~RectangularKernel.cdf
      ~RectangularKernel.icdf
      ~RectangularKernel.is_symmetric
      ~RectangularKernel.median_index
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RectangularKernel.min_cutoff
   
   